==> immutable-collection-encodings-1.4-sources.jar: com/hubspot/immutable/collection/encoding/ImmutableListEncodingEnabled.java <==
package com.hubspot.immutable.collection.encoding;

import org.immutables.encode.EncodingMetadata;

@EncodingMetadata(
  name = "com.hubspot.immutable.collection.encoding.ImmutableListEncoding",
  imports = {
  },
  typeParams = {"T"},
  elements = {
    @EncodingMetadata.Element(
      name = "field",
      tags = {"IMPL", "PRIVATE", "FINAL", "FIELD"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {},
      code = "com.google.common.collect.ImmutableList.of()",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "of",
      tags = {"STATIC", "PRIVATE", "FROM"},
      naming = "*_of",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {"input: java.util.Collection<? extends T>"},
      code = "{\nreturn com.google.common.collect.ImmutableList.copyOf(@^input);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "toString",
      tags = {"PRIVATE", "TO_STRING", "SYNTH"},
      naming = "*_toString",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {},
      code = "{\nreturn @:getImmutableList().toString();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "hashCode",
      tags = {"PRIVATE", "HASH_CODE", "SYNTH"},
      naming = "*_hashCode",
      stdNaming = "NONE",
      type = "int",
      typeParams = {},
      params = {},
      code = "{\nreturn @:getImmutableList().hashCode();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "equals",
      tags = {"PRIVATE", "EQUALS", "SYNTH"},
      naming = "*_equals",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {"other: com.hubspot.immutable.collection.encoding.ImmutableListEncoding<T>"},
      code = "{\nreturn this.@:getImmutableList().equals(@^other.@:getImmutableList())\n;}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "build",
      tags = {"BUILDER", "PRIVATE", "BUILD"},
      naming = "*_build",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {},
      code = "{\nif (@@builder != null) {\nreturn @@builder.build();\n} else if (@@list != null) {\nreturn @@list;\n} else {\nreturn com.google.common.collect.ImmutableList.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getImmutableList",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {},
      code = "{\nreturn @@field;\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getList",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "java.util.List<T>",
      typeParams = {},
      params = {},
      code = "{\nreturn @@field;\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "withCollectionVarargs",
      tags = {"COPY"},
      naming = "*",
      stdNaming = "WITH",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {"elements: T..."},
      code = "{\nreturn com.google.common.collect.ImmutableList.copyOf(@^elements);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "withCollection",
      tags = {"COPY"},
      naming = "*",
      stdNaming = "WITH",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {"elements: java.lang.Iterable<? extends T>"},
      code = "{\nreturn com.google.common.collect.ImmutableList.copyOf(@^elements);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "list",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_list",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "builder",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_builder",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList.Builder<T>",
      typeParams = {},
      params = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "add",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "ADD",
      type = "void",
      typeParams = {},
      params = {"element: T..."},
      code = "{\nif (@@builder != null) {\n@@builder.add(@^element);\n} else if (@@list != null) {\n@@builder = com.google.common.collect.ImmutableList.<@^T>builderWithExpectedSize(@@list.size() + 1)\n.addAll(@@list)\n.add(@^element);\n@@list = null;\n} else {\n@@builder = com.google.common.collect.ImmutableList.builder();\n@@builder.add(@^element);\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "addAll",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "ADD_ALL",
      type = "void",
      typeParams = {},
      params = {"elements: java.lang.Iterable<? extends T>"},
      code = "{\nif (@@builder != null) {\n@@builder.addAll(@^elements);\n} else if (@@list != null) {\nint additionalSize = 0;\nif (@^elements instanceof java.util.Collection) {\nadditionalSize = ((java.util.Collection<? extends @^T>) @^elements).size();\n}\n@@builder = com.google.common.collect.ImmutableList.<@^T>builderWithExpectedSize(@@list.size() + additionalSize)\n.addAll(@@list)\n.addAll(@^elements);\n@@list = null;\n} else {\nif (@^elements instanceof com.google.common.collect.ImmutableCollection) {\n@:set(@^elements);\n} else if (@^elements instanceof java.util.Collection) {\n@@builder = com.google.common.collect.ImmutableList.builderWithExpectedSize(((java.util.Collection<? extends @^T>) @^elements).size());\n@@builder.addAll(@^elements);\n} else {\n@@builder = com.google.common.collect.ImmutableList.builder();\n@@builder.addAll(@^elements);\n}\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "set",
      tags = {"BUILDER", "INIT", "COPY"},
      naming = "*",
      stdNaming = "INIT",
      type = "void",
      typeParams = {},
      params = {"input: java.lang.Iterable<? extends T>"},
      code = "{\n@@list = com.google.common.collect.ImmutableList.copyOf(@^input);\n@@builder = null;\n}",
      thrown = {}
    )
  }
)
public @interface ImmutableListEncodingEnabled {}

==> immutable-collection-encodings-1.11.0-sources.jar: com/hubspot/immutable/collection/encoding/ImmutableListEncodingEnabled.java <==
package com.hubspot.immutable.collection.encoding;

import org.immutables.encode.EncodingMetadata;

@EncodingMetadata(
  name = "com.hubspot.immutable.collection.encoding.ImmutableListEncoding",
  imports = {
  },
  typeParams = {"T"},
  elements = {
    @EncodingMetadata.Element(
      name = "field",
      tags = {"IMPL", "PRIVATE", "FINAL", "FIELD"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "of",
      tags = {"STATIC", "PRIVATE", "FROM"},
      naming = "*_of",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {"input: java.util.Collection<? extends T>"},
      doc = {},
      annotations = {},
      code = "{\nreturn com.google.common.collect.ImmutableList.copyOf(@^input);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "toString",
      tags = {"PRIVATE", "TO_STRING", "SYNTH"},
      naming = "*_toString",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nreturn @:getImmutableList().toString();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "hashCode",
      tags = {"PRIVATE", "HASH_CODE", "SYNTH"},
      naming = "*_hashCode",
      stdNaming = "NONE",
      type = "int",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nreturn @:getImmutableList().hashCode();\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "equals",
      tags = {"PRIVATE", "EQUALS", "SYNTH"},
      naming = "*_equals",
      stdNaming = "NONE",
      type = "java.lang.String",
      typeParams = {},
      params = {"other: com.hubspot.immutable.collection.encoding.ImmutableListEncoding<T>"},
      doc = {},
      annotations = {},
      code = "{\nreturn this.@:getImmutableList().equals(@^other.@:getImmutableList())\n;}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "build",
      tags = {"BUILDER", "PRIVATE", "BUILD"},
      naming = "*_build",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nif (@@builder != null) {\nreturn @@builder.build();\n} else if (@@list != null) {\nreturn @@list;\n} else {\nreturn com.google.common.collect.ImmutableList.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "isSet",
      tags = {"BUILDER", "PRIVATE", "IS_INIT"},
      naming = "*_isSet",
      stdNaming = "NONE",
      type = "boolean",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nreturn @@list != null || @@builder != null;\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getImmutableList",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nif (@@field != null) {\nreturn @@field;\n} else {\nreturn com.google.common.collect.ImmutableList.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "getList",
      tags = {"EXPOSE"},
      naming = "*",
      stdNaming = "NONE",
      type = "java.util.List<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "{\nif (@@field != null) {\nreturn @@field;\n} else {\nreturn com.google.common.collect.ImmutableList.of();\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "withCollectionVarargs",
      tags = {"COPY"},
      naming = "*",
      stdNaming = "WITH",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {"elements: T..."},
      doc = {},
      annotations = {},
      code = "{\nreturn com.google.common.collect.ImmutableList.copyOf(@^elements);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "withCollection",
      tags = {"COPY"},
      naming = "*",
      stdNaming = "WITH",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {"elements: java.lang.Iterable<? extends T>"},
      doc = {},
      annotations = {},
      code = "{\nreturn com.google.common.collect.ImmutableList.copyOf(@^elements);\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "list",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_list",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "builder",
      tags = {"BUILDER", "PRIVATE", "FIELD"},
      naming = "*_builder",
      stdNaming = "NONE",
      type = "com.google.common.collect.ImmutableList.Builder<T>",
      typeParams = {},
      params = {},
      doc = {},
      annotations = {},
      code = "null",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "add",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "ADD",
      type = "void",
      typeParams = {},
      params = {"element: T..."},
      doc = {},
      annotations = {},
      code = "{\nif (@@builder != null) {\n@@builder.add(@^element);\n} else if (@@list != null) {\n@@builder =\ncom.google.common.collect.ImmutableList\n.<@^T>builderWithExpectedSize(@@list.size() + 1)\n.addAll(@@list)\n.add(@^element);\n@@list = null;\n} else {\n@@builder = com.google.common.collect.ImmutableList.builder();\n@@builder.add(@^element);\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "addAll",
      tags = {"BUILDER", "INIT"},
      naming = "*",
      stdNaming = "ADD_ALL",
      type = "void",
      typeParams = {},
      params = {"elements: java.lang.Iterable<? extends T>"},
      doc = {},
      annotations = {},
      code = "{\nif (@@builder != null) {\n@@builder.addAll(@^elements);\n} else if (@@list != null) {\nint additionalSize = 0;\nif (@^elements instanceof java.util.Collection) {\nadditionalSize = ((java.util.Collection<? extends @^T>) @^elements).size();\n}\n@@builder =\ncom.google.common.collect.ImmutableList\n.<@^T>builderWithExpectedSize(@@list.size() + additionalSize)\n.addAll(@@list)\n.addAll(@^elements);\n@@list = null;\n} else {\nif (@^elements instanceof com.google.common.collect.ImmutableCollection) {\n@:set(@^elements);\n} else if (@^elements instanceof java.util.Collection) {\n@@builder =\ncom.google.common.collect.ImmutableList.builderWithExpectedSize(\n((java.util.Collection<? extends @^T>) @^elements).size()\n);\n@@builder.addAll(@^elements);\n} else {\n@@builder = com.google.common.collect.ImmutableList.builder();\n@@builder.addAll(@^elements);\n}\n}\n}",
      thrown = {}
    ),
    @EncodingMetadata.Element(
      name = "set",
      tags = {"BUILDER", "INIT", "COPY"},
      naming = "*",
      stdNaming = "INIT",
      type = "void",
      typeParams = {},
      params = {"input: java.lang.Iterable<? extends T>"},
      doc = {},
      annotations = {},
      code = "{\n@@list = com.google.common.collect.ImmutableList.copyOf(@^input);\n@@builder = null;\n}",
      thrown = {}
    )
  }
)
public @interface ImmutableListEncodingEnabled {}
